@@ -1,7 +1,6 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HUNCHENTOOT; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/hunchentoot/cookie.lisp,v 1.8 2008/02/13 16:02:17 edi Exp $
 
-;;; Copyright (c) 2004-2009, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2004-2010, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -43,6 +42,11 @@ when sent to the browser.")
             :initform nil
             :accessor cookie-expires
             :documentation "The time \(a universal time) when the
+cookie expires \(or NIL).")
+   (max-age :initarg :max-age
+            :initform nil
+            :accessor cookie-max-age
+            :documentation "The time delta \(in seconds) after which the
 cookie expires \(or NIL).")
    (path :initarg :path
          :initform nil
@@ -87,7 +91,7 @@ REPLY object REPLY. If a cookie with the same name
         (push (cons name cookie) (cookies-out reply))
         cookie))))
 
-(defun set-cookie (name &key (value "") expires path domain secure http-only (reply *reply*))
+(defun set-cookie (name &key (value "") expires max-age path domain secure http-only (reply *reply*))
   "Creates a cookie object from the parameters provided and adds
 it to the outgoing cookies of the REPLY object REPLY. If a cookie
 with the name NAME \(case-sensitive) already exists, it is
@@ -96,6 +100,7 @@ replaced."
                               :name name
                               :value value
                               :expires expires
+                              :max-age max-age
                               :path path
                               :domain domain
                               :secure secure
@@ -111,11 +116,12 @@ replaced."
   "Converts the COOKIE object COOKIE to a string suitable for a
 'Set-Cookie' header to be sent to the client."
   (format nil
-          "~A=~A~:[~;~:*; expires=~A~]~:[~;~:*; path=~A~]~:[~;~:*; domain=~A~]~:[~;; secure~]~:[~;; HttpOnly~]"
+          "~A=~A~@[; Expires=~A~]~@[; Max-Age=~A~]~@[; Domain=~A~]~@[; Path=~A~]~:[~;; Secure~]~:[~;; HttpOnly~]"
           (cookie-name cookie)
-          (url-encode (format nil "~A" (cookie-value cookie)) +utf-8+)
+          (cookie-value cookie)
           (cookie-date (cookie-expires cookie))
-          (cookie-path cookie)
+          (cookie-max-age cookie)
           (cookie-domain cookie)
+          (cookie-path cookie)
           (cookie-secure cookie)
-          (cookie-http-only cookie)))
\ No newline at end of file
+          (cookie-http-only cookie)))
