@@ -139,7 +139,7 @@ supposed to be of content type 'multipart/form-data'."
                            "NAME"
                            (rfc2388:header-parameters content-disposition-header)))
           when name
-          collect (cons name
+          collect (cons (convert-hack name external-format)
                         (let ((contents (rfc2388:mime-part-contents part)))
                           (if (pathnamep contents)
                             (list contents
@@ -587,15 +587,27 @@ REQUEST."
   any directory traversals or explicit device or host fields.  Returns
   NIL if the path is not acceptable."
   (when (every #'graphic-char-p path)
-    (let* ((pathname (pathname (remove #\\ (regex-replace "^/*" path ""))))
+    (let* ((pathname (#+sbcl sb-ext:parse-native-namestring
+                      #+ccl ccl:native-to-pathname
+                      ;; Just disallow anything with :wild components later.
+                      #-(or ccl sbcl) parse-namestring
+                      (remove #\\ (regex-replace "^/*" path ""))))
            (directory (pathname-directory pathname)))
       (when (and (or (null (pathname-host pathname))
-                     (equal (pathname-host pathname) (pathname-host *default-pathname-defaults*)))
+                     (equal (pathname-host pathname)
+                            (pathname-host *default-pathname-defaults*)))
                  (or (null (pathname-device pathname))
-                     (equal (pathname-device pathname) (pathname-device *default-pathname-defaults*)))
+                     (equal (pathname-device pathname)
+                            (pathname-device *default-pathname-defaults*)))
                  (or (null directory)
                      (and (eql (first directory) :relative)
-                          (every #'stringp (rest directory))))) ; only string components, no :UP traversals
+                          ;; only string components, no :UP traversals or :WILD
+                          (every #'stringp (rest directory))))
+                 #-(or sbcl ccl) ;; parse-native-namestring should handle this
+                 (and
+                  (typep (pathname-name pathname) '(or null string)) ; no :WILD
+                  (typep (pathname-type pathname) '(or null string)))
+                 (not (equal (file-namestring pathname) "..")))
         pathname))))
 
 (defun request-pathname (&optional (request *request*) drop-prefix)
@@ -603,7 +615,7 @@ REQUEST."
 If DROP-PREFIX is given, pathname construction starts at the first path
 segment after the prefix.
 "
-  (let ((path (url-decode (script-name request))))
+  (let ((path (script-name request)))
     (if drop-prefix
         (when (starts-with-p path drop-prefix)
           (parse-path (subseq path (length drop-prefix))))
